@@ -12,18 +12,10 @@ package Gitolite::Common;
           usage                             tsh_run
           gen_lfn
           gl_log
-
-          dd
-          t_start
-          t_lap
-
-          ssh_fingerprint_file
-          ssh_fingerprint_line
 );
 #>>>
 use Exporter 'import';
 use File::Path qw(mkpath);
-use File::Temp qw(tempfile);
 use Carp qw(carp cluck croak confess);
 
 use strict;
@@ -52,13 +44,15 @@ sub trace {
     return unless defined( $ENV{D} );
 
     my $level = shift; return if $ENV{D} < $level;
+    my $args = ''; $args = join( ", ", @_ ) if @_;
     my $sub = ( caller 1 )[3] || ''; $sub =~ s/.*://;
     if ( not $sub ) {
         $sub = (caller)[1];
         $sub =~ s(.*/(.*))(($1));
     }
-    $sub .= ' ' x ( 31 - length($sub) );
-    say2 "$level\t$sub\t", join( "\t", @_ );
+    $sub .= ' ' x ( 32 - length($sub) );
+    say2 "TRACE $level $sub", ( @_ ? shift : () );
+    say2( "TRACE $level " . ( " " x 32 ), $_ ) for @_;
 }
 
 sub dbg {
@@ -69,29 +63,6 @@ sub dbg {
     }
 }
 
-sub dd {
-    local $ENV{D} = 1;
-    dbg(@_);
-}
-
-{
-    my %start_times;
-
-    eval "require Time::HiRes";
-    # we just ignore any errors from this; nothing needs to be done as long as
-    # no code *calls* either of the next two functions.
-
-    sub t_start {
-        my $name = shift || 'default';
-        $start_times{$name} = [ Time::HiRes::gettimeofday() ];
-    }
-
-    sub t_lap {
-        my $name = shift || 'default';
-        return Time::HiRes::tv_interval( $start_times{$name} );
-    }
-}
-
 sub _warn {
     gl_log( 'warn', @_ );
     if ( $ENV{D} and $ENV{D} >= 3 ) {
@@ -117,20 +88,19 @@ sub _die {
 $SIG{__DIE__} = \&_die;
 
 sub usage {
+    _warn(shift) if @_;
     my $script = (caller)[1];
-    my $function = shift if @_ and $_[0] =~ /^[\w-]+$/;
-    $function ||= ( ( ( caller(1) )[3] ) || ( ( caller(0) )[3] ) );
+    my $function = ( ( ( caller(1) )[3] ) || ( ( caller(0) )[3] ) );
     $function =~ s/.*:://;
     my $code = slurp($script);
     $code =~ /^=for $function\b(.*?)^=cut/sm;
-    say( $1 ? $1 : "...no usage message for '$function' in $script" );
+    say2( $1 ? $1 : "...no usage message in $script" );
     exit 1;
 }
 
 sub _mkdir {
-    # It's not an error if the directory exists, but it is an error if it
-    # doesn't exist and we can't create it. This includes not guaranteeing
-    # dead symlinks or if mkpath traversal is blocked by a file.
+    # it's not an error if the directory exists, but it is an error if it
+    # doesn't exist and we can't create it
     my $dir  = shift;
     my $perm = shift;    # optional
     return if -d $dir;
@@ -210,7 +180,6 @@ sub sort_u {
 
 sub cleanup_conf_line {
     my $line = shift;
-    return $line if $line =~ /^# \S+ \d+$/;
 
     # kill comments, but take care of "#" inside *simple* strings
     $line =~ s/^((".*?"|[^#"])*)#.*/$1/;
@@ -230,15 +199,12 @@ sub cleanup_conf_line {
         # receiving *any* arg invalidates cache)
         return \@phy_repos if ( @phy_repos and not @_ );
 
-        my $cmd = 'find . ' . ($Gitolite::Rc::rc{REPO_SYMLINKS} || '') . ' -name "*.git" -prune';
-        for my $repo (`$cmd`) {
+        for my $repo (`find . -name "*.git" -prune`) {
             chomp($repo);
-            $repo =~ s/\.git$//;
-            $repo =~ s(^\./)();
-            push @phy_repos, $repo unless $repo =~ m(/$);
-                # tolerate bare repos within ~/repositories but silently ignore them
+            $repo =~ s(\./(.*)\.git$)($1);
+            push @phy_repos, $repo;
         }
-        trace( 3, scalar(@phy_repos) . " physical repos found" );
+        trace( 2, scalar(@phy_repos) . " physical repos found" );
         return sort_u( \@phy_repos );
     }
 }
@@ -272,9 +238,6 @@ sub gen_lfn {
     return $template;
 }
 
-my $log_dest;
-my $syslog_opened = 0;
-END { closelog() if $syslog_opened; }
 sub gl_log {
     # the log filename and the timestamp come from the environment.  If we get
     # called even before they are set, we have no choice but to dump to STDERR
@@ -287,94 +250,23 @@ sub gl_log {
     my $ts = gen_ts();
     my $tid = $ENV{GL_TID} ||= $$;
 
-    $log_dest = $Gitolite::Rc::rc{LOG_DEST} || '' if not defined $log_dest;
-
-    # log (update records only) to "gl-log" in the bare repo dir; this is to
-    # make 'who-pushed' more efficient.  Since this is only for the update
-    # records, it is not a replacement for the other two types of logging.
-    if ($log_dest =~ /repo-log/ and $_[0] eq 'update') {
-        # if the log line is 'update', we're already in the bare repo dir
-        open my $lfh, ">>", "gl-log" or _die "open gl-log failed: $!";
-        print $lfh "$ts\t$tid\t$msg\n";
-        close $lfh;
-    }
-
-    # syslog
-    if ($log_dest =~ /syslog/) {            # log_dest *includes* syslog
-        if ($syslog_opened == 0) {
-            require Sys::Syslog;
-            Sys::Syslog->import(qw(:standard));
-
-            openlog("gitolite" . ( $ENV{GL_TID} ? "[$ENV{GL_TID}]" : "" ), "pid", "local0");
-            $syslog_opened = 1;
-        }
-
-        # gl_log is called either directly, or, if the rc variable LOG_EXTRA
-        # is set, from trace(1, ...).  The latter use is considered additional
-        # info for troubleshooting.  Trace prefixes a tab to the arguments
-        # before calling gl_log, to visually set off such lines in the log
-        # file.  Although syslog eats up that leading tab, we use it to decide
-        # the priority/level of the syslog message.
-        syslog( ( $msg =~ /^\t/ ? 'debug' : 'info' ), "%s", $msg);
-
-        return if $log_dest !~ /normal/;
-    }
-
     my $fh;
     logger_plus_stderr( "errors found before logging could be setup", "$msg" ) if not $ENV{GL_LOGFILE};
     open my $lfh, ">>", $ENV{GL_LOGFILE}
-      or logger_plus_stderr( "errors found but logfile could not be created", "$ENV{GL_LOGFILE}: $!", "$msg" );
+      or logger_plus_stderr( "errors found before logfile could be created", "$msg" );
     print $lfh "$ts\t$tid\t$msg\n";
     close $lfh;
 }
 
 sub logger_plus_stderr {
     open my $fh, "|-", "logger" or confess "it's really not my day is it...?\n";
-    for (@_) {
+    for ( @_ ) {
         print STDERR "FATAL: $_\n";
         print $fh "FATAL: $_\n";
     }
     exit 1;
 }
 
-# ----------------------------------------------------------------------
-# Get the SSH fingerprint of a file
-# If the fingerprint cannot be parsed, it will be undef
-# In a scalar context, returns the fingerprint
-# In a list context, returns (fingerprint, output) where output
-# is the raw output of the ssh-keygen command
-sub ssh_fingerprint_file {
-    my $in = shift;
-    -f $in or die "file not found: $in\n";
-    my $fh;
-    open( $fh, "ssh-keygen -l -f $in |" ) or die "could not fork: $!\n";
-    my $output = <$fh>;
-    chomp $output;
-    # dbg("fp = $fp");
-    close $fh;
-    # Return a valid fingerprint or undef
-    my $fp = undef;
-    if($output =~ /((?:MD5:)?(?:[0-9a-f]{2}:){15}[0-9a-f]{2})/i or
-       $output =~ m{((?:RIPEMD|SHA)\d+:[A-ZA-z0-9+/=]+)}i) {
-        $fp = $1;
-    }
-    return wantarray ? ($fp, $output) : $fp;
-}
-
-# Get the SSH fingerprint of a line of text
-# If the fingerprint cannot be parsed, it will be undef
-# In a scalar context, returns the fingerprint
-# In a list context, returns (fingerprint, output) where output
-# is the raw output of the ssh-keygen command
-sub ssh_fingerprint_line {
-    my ( $fh, $fn ) = tempfile();
-    print $fh shift() . "\n";
-    close $fh;
-    my ($fp,$output) = ssh_fingerprint_file($fn);
-    unlink $fn;
-    return wantarray ? ($fp,$output) : $fp;
-}
-
 # ----------------------------------------------------------------------
 
 # bare-minimum subset of 'Tsh' (see github.com/sitaramc/tsh)
