@@ -10,9 +10,10 @@ package Gitolite::Conf;
 );
 
 use Exporter 'import';
+use Getopt::Long;
 
-use Gitolite::Rc;
 use Gitolite::Common;
+use Gitolite::Rc;
 use Gitolite::Conf::Sugar;
 use Gitolite::Conf::Store;
 
@@ -41,11 +42,9 @@ sub compile {
 
 sub parse {
     my $lines = shift;
-    trace( 3, scalar(@$lines) . " lines incoming" );
+    trace( 2, scalar(@$lines) . " lines incoming" );
 
-    my ( $fname, $lnum );
     for my $line (@$lines) {
-        ( $fname, $lnum ) = ( $1, $2 ), next if $line =~ /^# (\S+) (\d+)$/;
         # user or repo groups
         if ( $line =~ /^(@\S+) = (.*)/ ) {
             add_to_group( $1, split( ' ', $2 ) );
@@ -58,7 +57,7 @@ sub parse {
 
             for my $ref (@refs) {
                 for my $user (@users) {
-                    add_rule( $perm, $ref, $user, $fname, $lnum );
+                    add_rule( $perm, $ref, $user );
                 }
             }
         } elsif ( $line =~ /^config (.+) = ?(.*)/ ) {
@@ -66,18 +65,15 @@ sub parse {
             $value =~ s/^['"](.*)["']$/$1/;
             my @validkeys = split( ' ', ( $rc{GIT_CONFIG_KEYS} || '' ) );
             push @validkeys, "gitolite-options\\..*";
-            my @matched = grep { $key =~ /^$_$/i } @validkeys;
+            my @matched = grep { $key =~ /^$_$/ } @validkeys;
             _die "git config '$key' not allowed\ncheck GIT_CONFIG_KEYS in the rc file" if ( @matched < 1 );
-            _die "bad config value '$value'" if $value =~ $UNSAFE_PATT;
-            while ( my ( $mk, $mv ) = each %{ $rc{SAFE_CONFIG} } ) {
-                $value =~ s/%$mk/$mv/g;
-            }
+            _die "bad value '$value'" if $value =~ $UNSAFE_PATT;
             add_config( 1, $key, $value );
         } elsif ( $line =~ /^subconf (\S+)$/ ) {
-            trace( 3, $line );
+            trace( 2, $line );
             set_subconf($1);
         } else {
-            _warn "syntax error, ignoring: '$line'";
+            _warn "?? $line";
         }
     }
     parse_done();
