@@ -27,7 +27,7 @@ sub explode {
     my ( $file, $subconf, $out ) = @_;
 
     # seed the 'seen' list if it's empty
-    $included{ device_inode("gitolite.conf") }++ unless %included;
+    $included{ device_inode("conf/gitolite.conf") }++ unless %included;
 
     my $fh = _open( "<", $file );
     while (<$fh>) {
@@ -43,7 +43,6 @@ sub explode {
             incsub( $1, $2, $3, $subconf, $out );
         } else {
             # normal line, send it to the callback function
-            push @{$out}, "# $file $.";
             push @{$out}, $line;
         }
     }
@@ -57,10 +56,10 @@ sub incsub {
 
     _die "invalid include/subconf file/glob '$include_glob'"
       unless $include_glob =~ /^"(.+)"$/
-      or $include_glob =~ /^'(.+)'$/;
+          or $include_glob =~ /^'(.+)'$/;
     $include_glob = $1;
 
-    trace( 3, $is_subconf, $include_glob );
+    trace( 2, $is_subconf, $include_glob );
 
     for my $file ( glob($include_glob) ) {
         _warn("included file not found: '$file'"), next unless -f $file;
@@ -104,7 +103,7 @@ sub already_included {
     return 0 unless $included{$file_id}++;
 
     _warn("$file already included");
-    trace( 3, "$file already included" );
+    trace( 2, "$file already included" );
     return 1;
 }
 
