@@ -8,7 +8,6 @@ package Gitolite::Conf::Load;
 
   access
   git_config
-  env_options
 
   option
   repo_missing
@@ -19,10 +18,9 @@ package Gitolite::Conf::Load;
 );
 
 use Exporter 'import';
-use Cwd;
 
-use Gitolite::Rc;
 use Gitolite::Common;
+use Gitolite::Rc;
 
 use strict;
 use warnings;
@@ -34,7 +32,6 @@ our $data_version = '';
 our %repos;
 our %one_repo;
 our %groups;
-our %patterns;
 our %configs;
 our %one_config;
 our %split_conf;
@@ -70,23 +67,13 @@ my $last_repo = '';
 
 sub access {
     my ( $repo, $user, $aa, $ref ) = @_;
-    trace( 2, $repo, $user, $aa, $ref );
+    _die "invalid repo '$repo'" if not( $repo and $repo =~ $REPOPATT_PATT );
     _die "invalid user '$user'" if not( $user and $user =~ $USERNAME_PATT );
-    sanity($repo);
-
-    my @rules;
-    my $deny_rules;
-
+    my $deny_rules = option( $repo, 'deny-rules' );
     load($repo);
-    @rules = rules( $repo, $user );
-    $deny_rules = option( $repo, 'deny-rules' );
 
     # sanity check the only piece the user can control
-    _die "invalid characters in ref or filename: '$ref'\n" unless $ref =~ m(^VREF/NAME/) or $ref =~ $REF_OR_FILENAME_PATT;
-    # apparently we can't always force sanity; at least what we *return*
-    # should be sane/safe.  This pattern is based on REF_OR_FILENAME_PATT.
-    ( my $safe_ref = $ref ) =~ s([^-0-9a-zA-Z._\@/+ :,])(.)g;
-    trace( 3, "safe_ref", $safe_ref ) if $ref ne $safe_ref;
+    _die "invalid characters in ref or filename: '$ref'\n" unless $ref =~ $REF_OR_FILENAME_PATT;
 
     # when a real repo doesn't exist, ^C is a pre-requisite for any other
     # check to give valid results.
@@ -98,72 +85,41 @@ sub access {
     # similarly, ^C must be denied if the repo exists
     if ( $aa eq '^C' and not repo_missing($repo) ) {
         trace( 2, "DENIED by existence" );
-        return "$aa $safe_ref $repo $user DENIED by existence";
+        return "$aa $ref $repo $user DENIED by existence";
     }
 
-    trace( 3, scalar(@rules) . " rules found" );
-
-    $rc{RULE_TRACE} = '';
+    my @rules = rules( $repo, $user );
+    trace( 2, scalar(@rules) . " rules found" );
     for my $r (@rules) {
-        $rc{RULE_TRACE} .= " " . $r->[0] . " ";
-
         my $perm = $r->[1];
         my $refex = $r->[2]; $refex =~ s(/USER/)(/$user/);
         trace( 3, "perm=$perm, refex=$refex" );
 
-        $rc{RULE_TRACE} .= "d";
         # skip 'deny' rules if the ref is not (yet) known
         next if $perm eq '-' and $ref eq 'any' and not $deny_rules;
 
-        $rc{RULE_TRACE} .= "r";
         # rule matches if ref matches or ref is any (see gitolite-shell)
         next unless $ref =~ /^$refex/ or $ref eq 'any';
 
-        $rc{RULE_TRACE} .= "D";
         trace( 2, "DENIED by $refex" ) if $perm eq '-';
-        return "$aa $safe_ref $repo $user DENIED by $refex" if $perm eq '-';
+        return "$aa $ref $repo $user DENIED by $refex" if $perm eq '-';
 
-        # For repo creation, perm will be C and aa will be "^C".  For branch
-        # access, $perm can be RW\+?(C|D|CD|DC)?M?, and $aa can be W, +, C or
-        # D, or any of these followed by "M".
-
-        # We need to turn $aa into a regex that can match a suitable $perm.
-        # This is trivially true for "^C", "W" and "D", but the others (+, C,
-        # M) need some tweaking.
-
-        # first, quote the '+':
+        # $perm can be RW\+?(C|D|CD|DC)?M?.  $aa can be W, +, C or D, or
+        # any of these followed by "M".
         ( my $aaq = $aa ) =~ s/\+/\\+/;
-        # if aa is just "C", the user is trying to create a *branch* (not a
-        # *repo*), so let's make the pattern clearer to reflect that.
-        $aaq = "RW.*C" if $aaq eq "C";
-        # if the aa is, say "WM", make this "W.*M" because the perm could be
-        # 'RW+M', 'RW+CDM' etc, and they are all valid:
         $aaq =~ s/M/.*M/;
-
-        $rc{RULE_TRACE} .= "A";
-
         # as far as *this* ref is concerned we're ok
         return $refex if ( $perm =~ /$aaq/ );
-
-        $rc{RULE_TRACE} .= "p";
     }
-    $rc{RULE_TRACE} .= " F";
-
     trace( 2, "DENIED by fallthru" );
-    return "$aa $safe_ref $repo $user DENIED by fallthru";
-}
-
-# cache control
-if ($rc{CACHE}) {
-    require Gitolite::Cache;
-    Gitolite::Cache::cache_wrap('Gitolite::Conf::Load::access');
+    return "$aa $ref $repo $user DENIED by fallthru";
 }
 
 sub git_config {
     my ( $repo, $key, $empty_values_OK ) = @_;
     $key ||= '.';
 
-    if ( repo_missing($repo) ) {
+    if (repo_missing($repo)) {
         load_common();
     } else {
         load($repo);
@@ -201,41 +157,16 @@ sub git_config {
     # now some of these will have an empty key; we need to delete them unless
     # we're told empty values are OK
     unless ($empty_values_OK) {
-        my ( $k, $v );
-        while ( ( $k, $v ) = each %ret ) {
+        my($k, $v);
+        while (($k, $v) = each %ret) {
             delete $ret{$k} if not $v;
         }
     }
 
-    my ( $k, $v );
-    my $creator = creator($repo);
-    while ( ( $k, $v ) = each %ret ) {
-        $v =~ s/%GL_REPO/$repo/g;
-        $v =~ s/%GL_CREATOR/$creator/g if $creator;
-        $ret{$k} = $v;
-    }
-
-    map { trace( 3, "$_", "$ret{$_}" ) } ( sort keys %ret ) if $ENV{D};
+    trace( 3, map { ( "$_" => "-> $ret{$_}" ) } ( sort keys %ret ) );
     return \%ret;
 }
 
-sub env_options {
-    return unless -f "$rc{GL_ADMIN_BASE}/conf/gitolite.conf-compiled.pm";
-    # prevent catch-22 during initial install
-
-    my $cwd = getcwd();
-
-    my $repo = shift;
-    map { delete $ENV{$_} } grep { /^GL_OPTION_/ } keys %ENV;
-    my $h = git_config( $repo, '^gitolite-options.ENV\.' );
-    while ( my ( $k, $v ) = each %$h ) {
-        next unless $k =~ /^gitolite-options.ENV\.(\w+)$/;
-        $ENV{ "GL_OPTION_" . $1 } = $v;
-    }
-
-    chdir($cwd);
-}
-
 sub option {
     my ( $repo, $option ) = @_;
     $option = "gitolite-options.$option";
@@ -244,20 +175,8 @@ sub option {
     return $ret->{$option};
 }
 
-sub sanity {
-    my ($repo, $patt) = @_;
-    $patt ||= $REPOPATT_PATT;
-
-    _die "invalid repo '$repo'" if not( $repo and $repo =~ $patt );
-    _die "'$repo' ends with a '/'"  if $repo =~ m(/$);
-    _die "'$repo' contains '..'"    if $repo =~ $REPONAME_PATT and $repo =~ m(\.\.);
-    _die "'$repo' contains '.git/'" if $repo =~ $REPONAME_PATT and $repo =~ m(\.git/);
-}
-
 sub repo_missing {
     my $repo = shift;
-    sanity($repo);
-
     return not -d "$rc{GL_REPO_BASE}/$repo.git";
 }
 
@@ -292,7 +211,7 @@ sub load_1 {
     trace( 3, $repo );
 
     if ( repo_missing($repo) ) {
-        trace( 1, "repo '$repo' missing" ) if $repo =~ $REPONAME_PATT;
+        trace( 1, "repo '$repo' missing" );
         return;
     }
     _chdir("$rc{GL_REPO_BASE}/$repo.git");
@@ -304,9 +223,9 @@ sub load_1 {
     }
 
     if ( -f "gl-conf" ) {
-        return if not $split_conf{$repo};
+        _warn "split conf not set, gl-conf present for '$repo'" if not $split_conf{$repo};
 
-        my $cc = "./gl-conf";
+        my $cc = "gl-conf";
         _die "parse '$cc' failed: " . ( $! or $@ ) unless do $cc;
 
         $last_repo = $repo;
@@ -324,7 +243,7 @@ sub load_1 {
 
     sub rules {
         my ( $repo, $user ) = @_;
-        trace( 3, $repo, $user );
+        trace( 3, "repo=$repo, user=$user" );
 
         return @cached if ( $lastrepo eq $repo and $lastuser eq $user and @cached );
 
@@ -336,7 +255,7 @@ sub load_1 {
 
         for my $r (@repos) {
             for my $u (@users) {
-                push @rules, @{ $repos{$r}{$u} } if exists $repos{$r} and exists $repos{$r}{$u};
+                push @rules, @{ $repos{$r}{$u} } if exists $repos{$r}{$u};
             }
         }
 
@@ -366,11 +285,9 @@ sub load_1 {
 sub memberships {
     trace( 3, @_ );
     my ( $type, $base, $repo ) = @_;
-    $repo ||= '';
-    my @ret;
     my $base2 = '';
 
-    @ret = ( $base, '@all' );
+    my @ret = ( $base, '@all' );
 
     if ( $type eq 'repo' ) {
         # first, if a repo, say, pub/sitaram/project, has a gl-creator file
@@ -385,16 +302,12 @@ sub memberships {
         }
     }
 
-    push @ret, @{ $groups{$base} } if exists $groups{$base};
-    push @ret, @{ $groups{$base2} } if $base2 and exists $groups{$base2};
-    for my $i ( keys %{ $patterns{groups} } ) {
-        if ( $base =~ /^$i$/ or $base2 and ( $base2 =~ /^$i$/ ) ) {
+    for my $i ( keys %groups ) {
+        if ( $base eq $i or $base =~ /^$i$/ or $base2 and ( $base2 eq $i or $base2 =~ /^$i$/ ) ) {
             push @ret, @{ $groups{$i} };
         }
     }
 
-    push @ret, @{ ext_grouplist($base) } if $type eq 'user' and $rc{GROUPLIST_PGM};
-
     if ( $type eq 'user' and $repo and not repo_missing($repo) ) {
         # find the roles this user has when accessing this repo and add those
         # in as groupnames he is a member of.  You need the already existing
@@ -402,6 +315,8 @@ sub memberships {
         push @ret, user_roles( $base, $repo, @ret );
     }
 
+    push @ret, @{ ext_grouplist($base) } if $type eq 'user' and $rc{GROUPLIST_PGM};
+
     @ret = @{ sort_u( \@ret ) };
     trace( 3, sort @ret );
     return @ret;
@@ -444,8 +359,6 @@ sub user_roles {
     for (@roles) {
         # READERS u3 u4 @g1
         s/^\s+//; s/ +$//; s/=/ /; s/\s+/ /g; s/^\@//;
-        next if /^#/;
-        next unless /\S/;
         my ( $role, @members ) = split;
         # role = READERS, members = u3, u4, @g1
         if ( $role ne 'CREATOR' and not $rc{ROLES}{$role} ) {
@@ -478,7 +391,8 @@ sub generic_name {
     $creator = creator($base);
 
     $base2 = $base;
-    $base2 =~ s(\b$creator\b)(CREATOR) if $creator;
+    $base2 =~ s(/$creator/)(/CREATOR/) if $creator;
+    $base2 =~ s(^$creator/)(CREATOR/)  if $creator;
     $base2 = '' if $base2 eq $base;    # if there was no change
 
     return $base2;
@@ -486,8 +400,6 @@ sub generic_name {
 
 sub creator {
     my $repo = shift;
-    sanity($repo);
-
     return ( $ENV{GL_USER} || '' ) if repo_missing($repo);
     my $f       = "$rc{GL_REPO_BASE}/$repo.git/gl-creator";
     my $creator = '';
@@ -592,42 +504,19 @@ sub list_repos {
 }
 
 =for list_memberships
-Usage:  gitolite list-memberships -u|-r <name>
+Usage:  gitolite list-memberships <name>
 
-List all groups a name is a member of.  One of the flags '-u' or '-r' is
-mandatory, to specify if the name is a user or a repo.
-
-For users, the output includes the result from GROUPLIST_PGM, if it is
-defined.  For repos, the output includes any repo patterns that the repo name
-matches, as well as any groups that contain those patterns.
+  - list all groups a name is a member of
+  - takes one user/repo name
 =cut
 
 sub list_memberships {
-    require Getopt::Long;
+    usage() if @_ and $_[0] eq '-h' or not @_;
 
-    my ( $user, $repo, $help );
-
-    Getopt::Long::GetOptionsFromArray(
-        \@_,
-        'user|u=s' => \$user,
-        'repo|r=s' => \$repo,
-        'help|h'   => \$help,
-    );
-    usage() if $help or ( not $user and not $repo );
+    my $name = shift;
 
     load_common();
-    my @m;
-
-    if ( $user and $repo ) {
-        # unsupported/undocumented except via "in_role()" in Easy.pm
-        @m = memberships( 'user', $user, $repo );
-    } elsif ($user) {
-        @m = memberships( 'user', $user );
-    } elsif ($repo) {
-        @m = memberships( 'repo', $repo );
-    }
-
-    @m = grep { $_ ne '@all' and $_ ne ( $user || $repo ) } @m;
+    my @m = memberships( '', $name );
     return ( sort_u( \@m ) );
 }
 
