@@ -26,8 +26,8 @@ use Data::Dumper;
 $Data::Dumper::Indent   = 1;
 $Data::Dumper::Sortkeys = 1;
 
-use Gitolite::Rc;
 use Gitolite::Common;
+use Gitolite::Rc;
 use Gitolite::Hooks::Update;
 use Gitolite::Hooks::PostUpdate;
 
@@ -63,27 +63,12 @@ sub add_to_group {
 }
 
 sub set_repolist {
-    my @in = @_;
-    @repolist = ();
-    # ...sanity checks
-    while (@in) {
-        $_ = shift @in;
-        if ( check_subconf_repo_disallowed( $subconf, $_ ) ) {
-            if ( exists $groups{$_} ) {
-                # groupname disallowed; try individual members now
-                ( my $g = $_ ) =~ s/^\@$subconf\./\@/;
-                _warn "expanding '$g'; this *may* slow down compilation";
-                unshift @in, keys %{ $groups{$_} };
-                next;
-            }
-            $ignored{$subconf}{$_} = 1;
-            next;
-        }
+    @repolist = @_;
 
+    # ...sanity checks
+    for (@repolist) {
         _warn "explicit '.git' extension ignored for $_.git" if s/\.git$//;
         _die "bad reponame '$_'" if $_ !~ $REPOPATT_PATT;
-
-        push @repolist, $_;
     }
 }
 
@@ -112,33 +97,21 @@ sub parse_users {
 }
 
 sub add_rule {
-    my ( $perm, $ref, $user, $fname, $lnum ) = @_;
-    _warn "doesn't make sense to supply a ref ('$ref') for 'R' rule"
-      if $perm eq 'R' and $ref ne 'refs/.*';
-    _warn "possible undeclared group '$user'"
-      if $user =~ /^@/
-      and not $groups{$user}
-      and not $rc{GROUPLIST_PGM}
-      and not special_group($user);
-    _die "bad ref '$ref'"   unless $ref =~ $REPOPATT_PATT;
+    my ( $perm, $ref, $user ) = @_;
+    _die "bad ref '$ref'"   unless $ref  =~ $REPOPATT_PATT;
     _die "bad user '$user'" unless $user =~ $USERNAME_PATT;
 
     $nextseq++;
-    store_rule_info( $nextseq, $fname, $lnum );
     for my $repo (@repolist) {
+        if ( check_subconf_repo_disallowed( $subconf, $repo ) ) {
+            my $repo = $repo;
+            $repo =~ s/^\@$subconf\./locally modified \@/;
+            $ignored{$subconf}{$repo} = 1;
+            next;
+        }
+
         push @{ $repos{$repo}{$user} }, [ $nextseq, $perm, $ref ];
     }
-
-    sub special_group {
-        # ok perl doesn't really have lexical subs (at least not the older
-        # perls I want to support) but let's pretend...
-        my $g = shift;
-        $g =~ s/^\@//;
-        return 1 if $g eq 'all' or $g eq 'CREATOR';
-        return 1 if $rc{ROLES}{$g};
-        return 0;
-    }
-
 }
 
 sub add_config {
@@ -180,9 +153,9 @@ sub new_repos {
     _chdir( $rc{GL_REPO_BASE} );
 
     # normal repos
-    my @repos = grep { $_ =~ $REPONAME_PATT and not /^@/ } ( sort keys %repos, sort keys %configs );
+    my @repos = grep { $_ =~ $REPONAME_PATT and not /^@/ } sort keys %repos;
     # add in members of repo groups
-    map { push @repos, keys %{ $groups{$_} } } grep { /^@/ and $_ ne '@all' } keys %repos;
+    map { push @repos, keys %{ $groups{$_} } } grep { /^@/ } keys %repos;
 
     for my $repo ( @{ sort_u( \@repos ) } ) {
         next unless $repo =~ $REPONAME_PATT;    # skip repo patterns
@@ -191,7 +164,7 @@ sub new_repos {
         # use gl-conf as a sentinel
         hook_1($repo) if -d "$repo.git" and not -f "$repo.git/gl-conf";
 
-        if ( not -d "$repo.git" ) {
+        if (not -d "$repo.git") {
             push @{ $rc{NEW_REPOS_CREATED} }, $repo;
             trigger( 'PRE_CREATE', $repo );
             new_repo($repo);
@@ -217,6 +190,7 @@ sub new_wild_repo {
     trigger( 'PRE_CREATE', $repo, $user, $aa );
     new_repo($repo);
     _print( "$repo.git/gl-creator", $user );
+    _print( "$repo.git/gl-perms", "$rc{DEFAULT_ROLE_PERMS}\n" ) if $rc{DEFAULT_ROLE_PERMS};
     trigger( 'POST_CREATE', $repo, $user, $aa );
 
     _chdir( $rc{GL_ADMIN_BASE} );
@@ -224,12 +198,13 @@ sub new_wild_repo {
 
 sub hook_repos {
     trace(3);
-
     # all repos, all hooks
     _chdir( $rc{GL_REPO_BASE} );
-    my $phy_repos = list_phy_repos(1);
 
-    for my $repo ( @{$phy_repos} ) {
+    for my $repo (`find . -name "*.git" -prune`) {
+        chomp($repo);
+        $repo =~ s/\.git$//;
+        $repo =~ s(^\./)();
         hook_1($repo);
     }
 }
@@ -253,8 +228,6 @@ sub parse_done {
     for my $ig ( sort keys %ignored ) {
         _warn "subconf '$ig' attempting to set access for " . join( ", ", sort keys %{ $ignored{$ig} } );
     }
-
-    close_rule_info();
 }
 
 # ----------------------------------------------------------------------
@@ -284,18 +257,15 @@ sub store_1 {
     # warning: writes and *deletes* it from %repos and %configs
     my ($repo) = shift;
     trace( 3, $repo );
-    return unless ( $repos{$repo} or $configs{$repo} ) and -d "$repo.git";
+    return unless $repos{$repo} and -d "$repo.git";
 
     my ( %one_repo, %one_config );
 
     open( my $compiled_fh, ">", "$repo.git/gl-conf" ) or return;
 
-    my $dumped_data = '';
-    if ( $repos{$repo} ) {
-        $one_repo{$repo} = $repos{$repo};
-        delete $repos{$repo};
-        $dumped_data = Data::Dumper->Dump( [ \%one_repo ], [qw(*one_repo)] );
-    }
+    $one_repo{$repo} = $repos{$repo};
+    delete $repos{$repo};
+    my $dumped_data = Data::Dumper->Dump( [ \%one_repo ], [qw(*one_repo)] );
 
     if ( $configs{$repo} ) {
         $one_config{$repo} = $configs{$repo};
@@ -314,8 +284,6 @@ sub store_common {
     my $cc = "conf/gitolite.conf-compiled.pm";
     my $compiled_fh = _open( ">", "$cc.new" );
 
-    my %patterns = ();
-
     my $data_version = glrc('current-data-version');
     trace( 3, "data_version = $data_version" );
     print $compiled_fh Data::Dumper->Dump( [$data_version], [qw(*data_version)] );
@@ -329,16 +297,7 @@ sub store_common {
         my %groups = %{ inside_out( \%groups ) };
         $dumped_data = Data::Dumper->Dump( [ \%groups ], [qw(*groups)] );
         print $compiled_fh $dumped_data;
-
-        # save patterns in %groups for faster handling of multiple repos, such
-        # as happens in the various POST_COMPILE scripts
-        for my $k ( keys %groups ) {
-            $patterns{groups}{$k} = 1 unless $k =~ $REPONAME_PATT;
-        }
     }
-
-    print $compiled_fh Data::Dumper->Dump( [ \%patterns ], [qw(*patterns)] ) if %patterns;
-
     print $compiled_fh Data::Dumper->Dump( [ \%split_conf ], [qw(*split_conf)] ) if %split_conf;
 
     close $compiled_fh or _die "close compiled-conf failed: $!\n";
@@ -390,19 +349,5 @@ sub inside_out {
     # %groups = ( 'bb' => [ '@bb', '@aa' ], 'cc' => [ '@bb', '@aa' ], 'dd' => [ '@bb' ]);
 }
 
-{
-    my $ri_fh = '';
-
-    sub store_rule_info {
-        $ri_fh = _open( ">", $rc{GL_ADMIN_BASE} . "/conf/rule_info" ) unless $ri_fh;
-        # $nextseq, $fname, $lnum
-        print $ri_fh join( "\t", @_ ) . "\n";
-    }
-
-    sub close_rule_info {
-        close $ri_fh or die "close rule_info file failed: $!";
-    }
-}
-
 1;
 
