@@ -9,14 +9,11 @@ use warnings;
 
 # setting a repo specific umask
 # ----------------------------------------------------------------------
-# this is for people who are too paranoid to trust e.g., gitweb's repo
-# exclusion logic, but not paranoid enough to put it on a different server
 
 =for usage
 
-  * In the rc file, add the line
-        'RepoUmask',
-    somewhere in the ENABLE list
+  * In the rc file, add 'RepoUmask::pre_git' and 'RepoUmask::post_create' to
+    the corresponding trigger lists.
 
   * For each repo that is to get a different umask than the default, add a
     line like this:
@@ -40,7 +37,6 @@ sub post_create {
     my $mode = "0" . sprintf("%o", $umask ^ 0777);
 
     system("chmod -R $mode $repo.git >&2");
-    system("find $repo.git -type f -exec chmod a-x '{}' \\;");
 }
 
 sub pre_git {
